@@ -8,9 +8,12 @@ Raise exceptions on failure, don't worry about "set" and "get" methods.
 Copyright (C) 2018, Ramona Optics, Inc.
 """
 
-from .illuminate import Illuminate  # noqa
-from .led_color import LEDColor  # noqa
+from .illuminate import Illuminate
 
 from ._version import get_versions
 __version__ = get_versions()['version']
 del get_versions
+
+__all__ = [
+    'Illuminate',
+]
