@@ -261,6 +261,7 @@ class Illuminate:
         self.serial = None
         self._led_positions = None
         self._help = None
+        self._led_state = None
         self._led_cache = []
         self._maximum_current = maximum_current
 
@@ -1018,6 +1019,11 @@ class Illuminate:
         self._update_led_state(value)
 
     def _update_led_state(self, led, force_clear=False):
+        # The LED state might not exist if the system hasn't booted up
+        # Therefore, skip any errors that may occur on "Unefined variable"
+        # self._led_state
+        if self._led_state is None:
+            return
         # Certain functions, like special patterns, or fill array
         # Will clear the LEDs regardless of the `autoclear` functionality
         # THerefore,allow them to add the force clear parameter
@@ -1240,8 +1246,8 @@ class Illuminate:
         """Calculate the maximum brightness for each color channel of an LED
         that won't exceed the TLC's internal current limit.
 
-        Paramters
-        ---------
+        Parameters
+        ----------
         num_leds: int
             The number of LEDs to be illuminated.
         color_ratio: (float, float, float)
@@ -1254,14 +1260,20 @@ class Illuminate:
             The maximum scaled brightness for each color channel.
         """
         uint16_max = 65535
+        color_ratio = np.asarray(color_ratio)
+        color_ratio = color_ratio / np.sum(color_ratio)
 
         # equation modified from TLC5955 driver
         total_brightness = (self.maximum_current * uint16_max /
                             (num_leds * self._scale_factor *
                              self.led_current_amps))
 
-        color_ratio = color_ratio / np.sum(color_ratio)
-        return total_brightness * color_ratio
+        max_brightness = total_brightness * color_ratio
+
+        max_one_led_brightness = np.max(max_brightness)
+        if max_one_led_brightness > 255:
+            max_brightness = max_brightness * 255 / max_one_led_brightness
+        return tuple(max_brightness)
 
     def trigger(self, index):
         """Output TTL trigger pulse to camera."""
